@@ -2,12 +2,11 @@ from abc import ABC
 from enum import Enum
 from typing import Callable, Dict, Iterable, List, Optional, Tuple, Type, TypeVar, Union
 
-from ..utils import _Ensure, _Enum, _Iterable
-from .serializable import Serializable
-from .type import Json
+from ...core.json.serializable import Json, Serializable
+from ...core.utils import _Ensure, _Enum, _Iterable
 
 
-class _JsonDecode(ABC):
+class JsonDecode(ABC):
     T = TypeVar("T", bound=Union[str, Serializable, Enum, bool])
     K = TypeVar("K", bound=Union[str, Enum])
     Decoder = Callable[[Json], Optional[T]]
@@ -25,38 +24,38 @@ class _JsonDecode(ABC):
             if isinstance(json, cls):
                 return json
             return None
-        elif issubclass(cls, Serializable):
+        if issubclass(cls, Serializable):
             result = cls.from_json(json)
             if not result is None and not isinstance(result, cls):
-                return _Ensure._raise_error_value(None, cls, type(result))
+                return _Ensure.raise_error_value(None, cls, type(result))
             return result  # type: ignore
-        elif issubclass(cls, Enum):
+        if issubclass(cls, Enum):
             return _Enum.parse_value(cls, json)  # type:ignore
-        raise ValueError("Unknown type to handle `{}`".format(type(json)))
+        raise ValueError(f"Unknown type to handle `{type(json).__name__}`")
 
     @staticmethod
     def decode_optional(json: Optional[Json], cls: Type[T], decoder: Optional[Decoder] = None) -> Optional[T]:
         if json is None:
             return None
-        return _JsonDecode.decode(json, cls, decoder)
+        return JsonDecode.decode(json, cls, decoder)
 
     @staticmethod
     def __decode_list(
         json: Union[Json, List[Json]], cls: Type[T], decoder: Optional[Decoder] = None
     ) -> Iterable[Optional[T]]:
         if not isinstance(json, List):
-            return _Ensure._raise_error_instance("json", List, type(json))
-        return map(lambda x: _JsonDecode.decode(x, cls, decoder), json)
+            return _Ensure.raise_error_instance("json", List, type(json))
+        return map(lambda x: JsonDecode.decode(x, cls, decoder), json)
 
     @staticmethod
     def decode_list(json: Union[Json, List[Json]], cls: Type[T], decoder: Optional[Decoder] = None) -> List[T]:
-        return list(_Iterable.not_none(_JsonDecode.__decode_list(json, cls, decoder)))
+        return list(_Iterable.FilterOptional(JsonDecode.__decode_list(json, cls, decoder)))
 
     @staticmethod
     def decode_list_optional(
         json: Union[Json, List[Json]], cls: Type[T], decoder: Optional[Decoder] = None
     ) -> List[Optional[T]]:
-        return list(_JsonDecode.__decode_list(json, cls, decoder))
+        return list(JsonDecode.__decode_list(json, cls, decoder))
 
     @staticmethod
     def decode_optional_list(
@@ -66,7 +65,7 @@ class _JsonDecode(ABC):
     ) -> Optional[List[T]]:
         if json is None:
             return None
-        return _JsonDecode.decode_list(json, cls, decoder)
+        return JsonDecode.decode_list(json, cls, decoder)
 
     @staticmethod
     def decode_optional_list_optional(
@@ -76,90 +75,90 @@ class _JsonDecode(ABC):
     ) -> Optional[List[Optional[T]]]:
         if json is None:
             return None
-        return _JsonDecode.decode_list_optional(json, cls, decoder)
+        return JsonDecode.decode_list_optional(json, cls, decoder)
 
     @staticmethod
     def decode_dict(
         json: Union[Json, Dict[str, Json]],
-        kcls: Type[K],
-        tcls: Type[T],
-        kDecoder: Optional[KDecoder] = None,
-        tDecoder: Optional[Decoder] = None,
+        k_cls: Type[K],
+        t_cls: Type[T],
+        k_decoder: Optional[KDecoder] = None,
+        t_decoder: Optional[Decoder] = None,
     ) -> Dict[K, T]:
-        m = _JsonDecode.__decode_dict_to_map(json, kcls, tcls, kDecoder, tDecoder)
-        f = _Iterable.tuple_not_none(m)
-        return dict(f)
+        mapped = JsonDecode.__decode_dict_to_map(json, k_cls, t_cls, k_decoder, t_decoder)
+        filtered = _Iterable.FilterTupleOptional(mapped)
+        return dict(filtered)
 
     @staticmethod
     def decode_dict_optional(
         json: Union[Json, Dict[str, Json]],
-        kcls: Type[K],
-        tcls: Type[T],
-        kDecoder: Optional[KDecoder] = None,
-        tDecoder: Optional[Decoder] = None,
+        k_cls: Type[K],
+        t_cls: Type[T],
+        k_decoder: Optional[KDecoder] = None,
+        t_decoder: Optional[Decoder] = None,
     ) -> Dict[K, Optional[T]]:
-        return dict(_JsonDecode.__decode_dict_to_map(json, kcls, tcls, kDecoder, tDecoder))
+        return dict(JsonDecode.__decode_dict_to_map(json, k_cls, t_cls, k_decoder, t_decoder))
 
     @staticmethod
     def decode_optional_dict(
         json: Optional[Union[Json, Dict[str, Json]]],
-        kcls: Type[K],
-        tcls: Type[T],
-        kDecoder: Optional[KDecoder] = None,
-        tDecoder: Optional[Decoder] = None,
+        k_cls: Type[K],
+        t_cls: Type[T],
+        k_decoder: Optional[KDecoder] = None,
+        t_decoder: Optional[Decoder] = None,
     ) -> Optional[Dict[K, T]]:
         if json is None:
             return None
-        return _JsonDecode.decode_dict(json, kcls, tcls, kDecoder, tDecoder)
+        return JsonDecode.decode_dict(json, k_cls, t_cls, k_decoder, t_decoder)
 
     @staticmethod
     def decode_optional_dict_optional(
         json: Optional[Union[Json, Dict[str, Json]]],
-        kcls: Type[K],
-        tcls: Type[T],
-        kDecoder: Optional[KDecoder] = None,
-        tDecoder: Optional[Decoder] = None,
+        k_cls: Type[K],
+        t_cls: Type[T],
+        k_decoder: Optional[KDecoder] = None,
+        t_decoder: Optional[Decoder] = None,
     ) -> Optional[Dict[K, Optional[T]]]:
         if json is None:
             return None
-        return _JsonDecode.decode_dict_optional(json, kcls, tcls, kDecoder, tDecoder)
+        return JsonDecode.decode_dict_optional(json, k_cls, t_cls, k_decoder, t_decoder)
 
     @staticmethod
     def __decode_dict_to_map(
         json: Union[Json, Dict[str, Json]],
-        kcls: Type[K],
-        tcls: Type[T],
-        kDecoder: Optional[KDecoder] = None,
-        tDecoder: Optional[Decoder] = None,
+        k_cls: Type[K],
+        t_cls: Type[T],
+        k_decoder: Optional[KDecoder] = None,
+        t_decoder: Optional[Decoder] = None,
     ) -> Iterable[Tuple[K, Optional[T]]]:
         if not isinstance(json, Dict):
-            return _Ensure._raise_error_instance("json", Dict, type(json))
+            return _Ensure.raise_error_instance("json", Dict, type(json))
         return map(
-            lambda x: _JsonDecode.__decode_dict_tuple(x, kcls, tcls, kDecoder, tDecoder),
+            lambda x: JsonDecode.__decode_dict_tuple(x, k_cls, t_cls, k_decoder, t_decoder),
             json.items(),
         )
 
     @staticmethod
     def __decode_dict_tuple(
-        input: Tuple[str, Json],
-        kcls: Type[K],
-        tcls: Type[T],
-        kDecoder: Optional[KDecoder] = None,
-        tDecoder: Optional[Decoder] = None,
+        value: Tuple[str, Json],
+        k_cls: Type[K],
+        t_cls: Type[T],
+        k_decoder: Optional[KDecoder] = None,
+        t_decoder: Optional[Decoder] = None,
     ) -> Tuple[K, Optional[T]]:
         return (
-            _JsonDecode.__decode_dict_key(input[0], kcls, kDecoder),
-            _JsonDecode.decode(input[1], tcls, tDecoder),
+            JsonDecode.__decode_dict_key(value[0], k_cls, k_decoder),
+            JsonDecode.decode(value[1], t_cls, t_decoder),
         )
 
     @staticmethod
-    def __decode_dict_key(key: str, kcls: Type[K], kDecoder: Optional[KDecoder] = None) -> K:
-        if kDecoder is None:
-            decoded = _JsonDecode.decode(key, kcls, None)
+    def __decode_dict_key(key: str, k_cls: Type[K], k_decoder: Optional[KDecoder] = None) -> K:
+        if k_decoder is None:
+            decoded = JsonDecode.decode(key, k_cls, None)
         else:
-            decoded = kDecoder(key)
+            decoded = k_decoder(key)
         if decoded is None:
-            raise ValueError('Unexpected dict key decode "{}" to `{}`'.format(key, kcls.__name__))
-        if isinstance(decoded, kcls):
+            raise ValueError(f'Unexpected dict key decode "{key}" to `{k_cls.__name__}`')
+        if isinstance(decoded, k_cls):
             return decoded
-        raise ValueError('Invalid decoded key "{}" as `{}`'.format(key, type(key)))
+        raise ValueError(f'Invalid decoded key "{key}" as `{type(key).__format__}`')
