@@ -1,7 +1,7 @@
 from .....core.utils import _Enum
+from .....model.argument.option.common._decoder import _DecodedOption
+from .....model.argument.option.long import LongOptionWithValue
 from .....model.build.mode import BuildMode
-from ..long import LongOptionWithValue
-from ._decoder import _DecodedOption
 
 __all__ = ["BuildModeOption"]
 
@@ -11,5 +11,5 @@ class BuildModeOption(LongOptionWithValue, _DecodedOption[BuildMode]):
         LongOptionWithValue.__init__(self, "build-mode", description)
         _DecodedOption.__init__(self, description)
 
-    def _convert(self, input: str) -> BuildMode:
-        return _Enum.parse_value(BuildMode, input)
+    def _convert(self, value: str) -> BuildMode:
+        return _Enum.parse_value(BuildMode, value)
