@@ -3,8 +3,8 @@ from __future__ import annotations
 from typing import Optional
 
 from ...core.utils import _Ensure
+from ...model.argument.arguments import Args
 from ...model.result import Result
-from ..argument import Args
 
 
 class TaskResult(Result):
@@ -23,12 +23,9 @@ class TaskResult(Result):
         )
 
     def __repr__(self) -> str:
-        return "{cls}(error={error}, success={success}, message={message}, args={args})".format(
-            cls=type(self).__name__,
-            error=self.error,
-            success=self.success,
-            message=self.message,
-            args=self.args,
+        return (
+            f"{type(self).__name__}(error={self.error}, "
+            + f"success={self.success}, message={self.message}, args={self.args})"
         )
 
 
