@@ -1,10 +1,10 @@
 from .....core.utils.task.subtask_parent_task import BaseSubtaskParentTask
-from .....model.task import *
 from .....model.task.group import TaskGroup
-from ...identity import AflutterTaskIdentity
-from .flavor import AflutterFlavorConfigTask
-from .platform import AflutterPlatformConfigTask
-from .refresh import AflutterConfigRefreshTask
+from .....model.task.task import *  # pylint: disable=wildcard-import
+from .....module.aflutter.identity import AflutterTaskIdentity
+from .....module.aflutter.task.config.flavor import AflutterFlavorConfigTask
+from .....module.aflutter.task.config.platform import AflutterPlatformConfigTask
+from .....module.aflutter.task.config.refresh import AflutterConfigRefreshTask
 
 __all__ = ["AflutterConfigIdentity"]
 
