@@ -1,6 +1,6 @@
-from .....model.task import *
-from .base import BaseConfigTask
-from .project import ProjectConfigTaskIdentity
+from .....model.task.task import *  # pylint: disable=wildcard-import
+from .....module.aflutter.task.config.base import BaseConfigTask
+from .....module.aflutter.task.config.project import ProjectConfigTaskIdentity
 
 
 class AflutterConfigRefreshTask(BaseConfigTask):
@@ -8,7 +8,7 @@ class AflutterConfigRefreshTask(BaseConfigTask):
         "refresh",
         "Update aflutter.json with aflutter style. Usefully after manually editing aflutter.json",
         [],
-        lambda: AflutterConfigRefreshTask(),
+        lambda: AflutterConfigRefreshTask(),  # pylint: disable=unnecessary-lambda
     )
 
     def describe(self, args: Args) -> str:
