@@ -1,12 +1,12 @@
 from ....core.utils import _Raise
 from ....model.task.group import TaskGroup
+from ....module.aflutter.identity import AflutterTaskIdentity
 from ....module.aflutter.task.config.config import AflutterConfigIdentity
+from ....module.aflutter.task.help import HelpTask
 from ....module.aflutter.task.project.init.runner import ProjectInitRunnerTask
 from ....module.aflutter.task.project.read import ProjectRead
 from ....module.aflutter.task.project.save import ProjectSave
-from ....module.aflutter.task.setup import AflutterSetupIdentity
-from ..identity import AflutterTaskIdentity
-from .help import HelpTask
+from ....module.aflutter.task.setup.setup import AflutterSetupIdentity
 
 __all__ = ["Root"]
 
