@@ -1,11 +1,15 @@
-from ..plugin import *
-from .task.build.stub import FlutterBuildStub
-from .task.config.build_param import FlutterBuildParamConfigTask
-from .task.exec import FlutterExecTask
-from .task.generator import FlutterGeneratorTask
-from .task.pub_get import FlutterPubGetIdentity
-from .task.setup.check import FlutterSetupCheckTask
-from .task.setup.setup import FlutterSetupTask
+from typing import Callable
+
+from ...model.task.group import TaskGroup
+from ...model.task.identity import TaskIdentity
+from ...module.flutter.task.build.stub import FlutterBuildStub
+from ...module.flutter.task.config.build_param import FlutterBuildParamConfigTask
+from ...module.flutter.task.exec import FlutterExecTask
+from ...module.flutter.task.generator import FlutterGeneratorTask
+from ...module.flutter.task.pub_get import FlutterPubGetIdentity
+from ...module.flutter.task.setup.check import FlutterSetupCheckTask
+from ...module.flutter.task.setup.setup import FlutterSetupTask
+from ...module.plugin import AflutterModulePlugin
 
 
 class FlutterModulePlugin(AflutterModulePlugin):
