@@ -1,7 +1,5 @@
-from typing import Callable
-
-from ...model.argument.option import Option
-from ...model.task import *
+from ...model.task.identity import *  # pylint: disable=wildcard-import
+from ...model.task.task import Task
 
 
 class UserTaskIdentity(TaskIdentity):
